==> mingw-w64-clang-i686-petsc-build-3.17.2-3-any.pkg.tar.zst: clang32/src/petsc-3.17.2/sto/include/petscconf.h <==
#if !defined(INCLUDED_PETSCCONF_H)
#define INCLUDED_PETSCCONF_H

#define MPI_Comm_create_errhandler(p_err_fun,p_errhandler) MPI_Errhandler_create((p_err_fun),(p_errhandler))
#define MPI_Comm_set_errhandler(comm,p_errhandler) MPI_Errhandler_set((comm),(p_errhandler))
#define MPI_Type_create_struct(count,lens,displs,types,newtype) MPI_Type_struct((count),(lens),(displs),(types),(newtype))
#define PETSC_ARCH "sto"
#define PETSC_ATTRIBUTEALIGNED(size) __attribute((aligned(size)))
#define PETSC_Alignx(a,b)   
#define PETSC_BLASLAPACK_UNDERSCORE 1
#define PETSC_CLANGUAGE_C 1
#define PETSC_CXX_RESTRICT __restrict
#define PETSC_DEPRECATED_ENUM(why) __attribute((deprecated))
#define PETSC_DEPRECATED_FUNCTION(why) __attribute((deprecated))
#define PETSC_DEPRECATED_MACRO(why) _Pragma(why)
#define PETSC_DEPRECATED_TYPEDEF(why) __attribute((deprecated))
#define PETSC_DIR "/c/M/mingw-w64-petsc/src/build-CLANG32/petsc-3.17.2"
#define PETSC_DIR_SEPARATOR '/'
#define PETSC_FUNCTION_NAME_C __func__
#define PETSC_FUNCTION_NAME_CXX __func__
#define PETSC_HAVE_ACCESS 1
#define PETSC_HAVE_ATOLL 1
#define PETSC_HAVE_ATTRIBUTEALIGNED 1
#define PETSC_HAVE_BUILTIN_EXPECT 1
#define PETSC_HAVE_C99_COMPLEX 1
#define PETSC_HAVE_CLOCK 1
#define PETSC_HAVE_CXX 1
#define PETSC_HAVE_CXX_COMPLEX 1
#define PETSC_HAVE_CXX_COMPLEX_FIX 1
#define PETSC_HAVE_CXX_DIALECT_CXX11 1
#define PETSC_HAVE_CXX_DIALECT_CXX14 1
#define PETSC_HAVE_CXX_DIALECT_CXX17 1
#define PETSC_HAVE_DIRECT_H 1
#define PETSC_HAVE_DOS_H 1
#define PETSC_HAVE_DOUBLE_ALIGN_MALLOC 1
#define PETSC_HAVE_ERF 1
#define PETSC_HAVE_FCNTL_H 1
#define PETSC_HAVE_FENV_H 1
#define PETSC_HAVE_FLOAT_H 1
#define PETSC_HAVE_FREELIBRARY 1
#define PETSC_HAVE_GETCOMPUTERNAME 1
#define PETSC_HAVE_GETCWD 1
#define PETSC_HAVE_GETLASTERROR 1
#define PETSC_HAVE_GETPROCADDRESS 1
#define PETSC_HAVE_GET_USER_NAME 1
#define PETSC_HAVE_HWLOC 1
#define PETSC_HAVE_IEEEFP_H 1
#define PETSC_HAVE_IMMINTRIN_H 1
#define PETSC_HAVE_INTTYPES_H 1
#define PETSC_HAVE_IO_H 1
#define PETSC_HAVE_ISINF 1
#define PETSC_HAVE_ISNAN 1
#define PETSC_HAVE_ISNORMAL 1
#define PETSC_HAVE_LARGE_INTEGER_U 1
#define PETSC_HAVE_LGAMMA 1
#define PETSC_HAVE_LOADLIBRARY 1
#define PETSC_HAVE_LOG2 1
#define PETSC_HAVE_LSEEK 1
#define PETSC_HAVE_MALLOC_H 1
#define PETSC_HAVE_MEMMOVE 1
#define PETSC_HAVE_MPIUNI 1
#define PETSC_HAVE_OPENBLAS 1
#define PETSC_HAVE_OPENMP 1
#define PETSC_HAVE_O_BINARY 1
#define PETSC_HAVE_PACKAGES ":blaslapack:hwloc:mathlib:mpi:openblas:openmp:"
#define PETSC_HAVE_POPEN 1
#define PETSC_HAVE_PTHREAD_H 1
#define PETSC_HAVE_RAND 1
#define PETSC_HAVE_SETJMP_H 1
#define PETSC_HAVE_SETLASTERROR 1
#define PETSC_HAVE_SLEEP 1
#define PETSC_HAVE_SNPRINTF 1
#define PETSC_HAVE_STDINT_H 1
#define PETSC_HAVE_STRCASECMP 1
#define PETSC_HAVE_STRICMP 1
#define PETSC_HAVE_STRINGS_H 1
#define PETSC_HAVE_SYS_PARAM_H 1
#define PETSC_HAVE_SYS_TIME_H 1
#define PETSC_HAVE_SYS_TYPES_H 1
#define PETSC_HAVE_TGAMMA 1
#define PETSC_HAVE_TIME 1
#define PETSC_HAVE_TIME_H 1
#define PETSC_HAVE_UNISTD_H 1
#define PETSC_HAVE_USLEEP 1
#define PETSC_HAVE_VA_COPY 1
#define PETSC_HAVE_VSNPRINTF 1
#define PETSC_HAVE_WINDOWSX_H 1
#define PETSC_HAVE_WINDOWS_H 1
#define PETSC_HAVE_WS2TCPIP_H 1
#define PETSC_HAVE_XMMINTRIN_H 1
#define PETSC_HAVE__ACCESS 1
#define PETSC_HAVE__GETCWD 1
#define PETSC_HAVE__LSEEK 1
#define PETSC_HAVE__MKDIR 1
#define PETSC_HAVE__PIPE 1
#define PETSC_HAVE__SLEEP 1
#define PETSC_HAVE___INT64 1
#define PETSC_IS_COLORING_MAX USHRT_MAX
#define PETSC_IS_COLORING_VALUE_TYPE short
#define PETSC_IS_COLORING_VALUE_TYPE_F integer2
#define PETSC_LEVEL1_DCACHE_LINESIZE 64
#define PETSC_LIB_DIR "/c/M/mingw-w64-petsc/src/build-CLANG32/petsc-3.17.2/sto/lib"
#define PETSC_MAX_PATH_LEN 260
#define PETSC_MEMALIGN 16
#define PETSC_MISSING_GETLINE 1
#define PETSC_MISSING_SIGALRM 1
#define PETSC_MISSING_SIGBUS 1
#define PETSC_MISSING_SIGCHLD 1
#define PETSC_MISSING_SIGCONT 1
#define PETSC_MISSING_SIGHUP 1
#define PETSC_MISSING_SIGKILL 1
#define PETSC_MISSING_SIGPIPE 1
#define PETSC_MISSING_SIGQUIT 1
#define PETSC_MISSING_SIGSTOP 1
#define PETSC_MISSING_SIGSYS 1
#define PETSC_MISSING_SIGTRAP 1
#define PETSC_MISSING_SIGTSTP 1
#define PETSC_MISSING_SIGURG 1
#define PETSC_MISSING_SIGUSR1 1
#define PETSC_MISSING_SIGUSR2 1
#define PETSC_MPICC_SHOW "Unavailable"
#define PETSC_MPIU_IS_COLORING_VALUE_TYPE MPI_UNSIGNED_SHORT
#define PETSC_NEEDS_UTYPE_TYPEDEFS 1
#define PETSC_PREFETCH_HINT_NTA _MM_HINT_NTA
#define PETSC_PREFETCH_HINT_T0 _MM_HINT_T0
#define PETSC_PREFETCH_HINT_T1 _MM_HINT_T1
#define PETSC_PREFETCH_HINT_T2 _MM_HINT_T2
#define PETSC_PYTHON_EXE "/usr/bin/python.exe"
#define PETSC_Prefetch(a,b,c) _mm_prefetch((const char*)(a),(c))
#define PETSC_REPLACE_DIR_SEPARATOR '\\'
#define PETSC_SIGNAL_CAST  
#define PETSC_SIZEOF_ENUM 4
#define PETSC_SIZEOF_INT 4
#define PETSC_SIZEOF_LONG 4
#define PETSC_SIZEOF_LONG_LONG 8
#define PETSC_SIZEOF_SHORT 2
#define PETSC_SIZEOF_SIZE_T 4
#define PETSC_SIZEOF_VOID_P 4
#define PETSC_SLSUFFIX ""
#define PETSC_UINTPTR_T uintptr_t
#define PETSC_UNUSED __attribute((unused))
#define PETSC_USE_AVX512_KERNELS 1
#define PETSC_USE_BACKWARD_LOOP 1
#define PETSC_USE_CTABLE 1
#define PETSC_USE_INFO 1
#define PETSC_USE_ISATTY 1
#define PETSC_USE_LOG 1
#define PETSC_USE_MALLOC_COALESCED 1
#define PETSC_USE_MICROSOFT_TIME 1
#define PETSC_USE_PROC_FOR_SIZE 1
#define PETSC_USE_REAL_SINGLE 1
#define PETSC_USE_SINGLE_LIBRARY 1
#define PETSC__BSD_SOURCE 1
#define PETSC__DEFAULT_SOURCE 1
#define PETSC_gid_t int
#define PETSC_uid_t int
#endif

==> mingw-w64-clang-i686-petsc-build-3.18.3-1-any.pkg.tar.zst: clang32/src/petsc-3.18.3/sto/include/petscconf.h <==
#if !defined(INCLUDED_PETSCCONF_H)
#define INCLUDED_PETSCCONF_H

#define MPI_Comm_create_errhandler(p_err_fun,p_errhandler) MPI_Errhandler_create((p_err_fun),(p_errhandler))
#define MPI_Comm_set_errhandler(comm,p_errhandler) MPI_Errhandler_set((comm),(p_errhandler))
#define MPI_Type_create_struct(count,lens,displs,types,newtype) MPI_Type_struct((count),(lens),(displs),(types),(newtype))
#define PETSC_ARCH "sto"
#define PETSC_ATTRIBUTEALIGNED(size) __attribute((aligned(size)))
#define PETSC_BLASLAPACK_UNDERSCORE 1
#define PETSC_CLANGUAGE_C 1
#define PETSC_CXX_RESTRICT __restrict
#define PETSC_DEPRECATED_ENUM(why) __attribute__((deprecated(why)))
#define PETSC_DEPRECATED_FUNCTION(why) __attribute__((deprecated(why)))
#define PETSC_DEPRECATED_MACRO(why) _Pragma(why)
#define PETSC_DEPRECATED_TYPEDEF(why) __attribute__((deprecated(why)))
#define PETSC_DIR "/c/M/mingw-w64-petsc/src/build-CLANG32/petsc-3.18.3"
#define PETSC_DIR_SEPARATOR '/'
#define PETSC_FUNCTION_NAME_C __func__
#define PETSC_FUNCTION_NAME_CXX __func__
#define PETSC_HAVE_ACCESS 1
#define PETSC_HAVE_ATOLL 1
#define PETSC_HAVE_ATTRIBUTEALIGNED 1
#define PETSC_HAVE_BUILTIN_EXPECT 1
#define PETSC_HAVE_C99_COMPLEX 1
#define PETSC_HAVE_CLOCK 1
#define PETSC_HAVE_CXX 1
#define PETSC_HAVE_CXX_COMPLEX 1
#define PETSC_HAVE_CXX_COMPLEX_FIX 1
#define PETSC_HAVE_CXX_DIALECT_CXX11 1
#define PETSC_HAVE_CXX_DIALECT_CXX14 1
#define PETSC_HAVE_CXX_DIALECT_CXX17 1
#define PETSC_HAVE_DIRECT_H 1
#define PETSC_HAVE_DOS_H 1
#define PETSC_HAVE_DOUBLE_ALIGN_MALLOC 1
#define PETSC_HAVE_ERF 1
#define PETSC_HAVE_FCNTL_H 1
#define PETSC_HAVE_FENV_H 1
#define PETSC_HAVE_FLOAT_H 1
#define PETSC_HAVE_FREELIBRARY 1
#define PETSC_HAVE_GETCOMPUTERNAME 1
#define PETSC_HAVE_GETCWD 1
#define PETSC_HAVE_GETLASTERROR 1
#define PETSC_HAVE_GETPROCADDRESS 1
#define PETSC_HAVE_GET_USER_NAME 1
#define PETSC_HAVE_HWLOC 1
#define PETSC_HAVE_IEEEFP_H 1
#define PETSC_HAVE_IMMINTRIN_H 1
#define PETSC_HAVE_INTTYPES_H 1
#define PETSC_HAVE_IO_H 1
#define PETSC_HAVE_ISINF 1
#define PETSC_HAVE_ISNAN 1
#define PETSC_HAVE_ISNORMAL 1
#define PETSC_HAVE_LARGE_INTEGER_U 1
#define PETSC_HAVE_LGAMMA 1
#define PETSC_HAVE_LOADLIBRARY 1
#define PETSC_HAVE_LOG2 1
#define PETSC_HAVE_LSEEK 1
#define PETSC_HAVE_MALLOC_H 1
#define PETSC_HAVE_MEMMOVE 1
#define PETSC_HAVE_MPIUNI 1
#define PETSC_HAVE_OPENBLAS 1
#define PETSC_HAVE_OPENMP 1
#define PETSC_HAVE_O_BINARY 1
#define PETSC_HAVE_PACKAGES ":blaslapack:hwloc:mathlib:mpi:openblas:openmp:"
#define PETSC_HAVE_POPEN 1
#define PETSC_HAVE_PTHREAD_H 1
#define PETSC_HAVE_RAND 1
#define PETSC_HAVE_SETJMP_H 1
#define PETSC_HAVE_SETLASTERROR 1
#define PETSC_HAVE_SLEEP 1
#define PETSC_HAVE_SNPRINTF 1
#define PETSC_HAVE_STDINT_H 1
#define PETSC_HAVE_STRCASECMP 1
#define PETSC_HAVE_STRICMP 1
#define PETSC_HAVE_STRINGS_H 1
#define PETSC_HAVE_SYS_PARAM_H 1
#define PETSC_HAVE_SYS_TIME_H 1
#define PETSC_HAVE_SYS_TYPES_H 1
#define PETSC_HAVE_TGAMMA 1
#define PETSC_HAVE_TIME 1
#define PETSC_HAVE_TIME_H 1
#define PETSC_HAVE_UNISTD_H 1
#define PETSC_HAVE_USLEEP 1
#define PETSC_HAVE_VA_COPY 1
#define PETSC_HAVE_VSNPRINTF 1
#define PETSC_HAVE_WINDOWSX_H 1
#define PETSC_HAVE_WINDOWS_H 1
#define PETSC_HAVE_WS2TCPIP_H 1
#define PETSC_HAVE_XMMINTRIN_H 1
#define PETSC_HAVE__ACCESS 1
#define PETSC_HAVE__GETCWD 1
#define PETSC_HAVE__LSEEK 1
#define PETSC_HAVE__MKDIR 1
#define PETSC_HAVE__PIPE 1
#define PETSC_HAVE__SLEEP 1
#define PETSC_HAVE___INT64 1
#define PETSC_IS_COLORING_MAX USHRT_MAX
#define PETSC_IS_COLORING_VALUE_TYPE short
#define PETSC_IS_COLORING_VALUE_TYPE_F integer2
#define PETSC_LEVEL1_DCACHE_LINESIZE 32
#define PETSC_LIB_DIR "/c/M/mingw-w64-petsc/src/build-CLANG32/petsc-3.18.3/sto/lib"
#define PETSC_MAX_PATH_LEN 260
#define PETSC_MEMALIGN 16
#define PETSC_MISSING_GETLINE 1
#define PETSC_MISSING_SIGALRM 1
#define PETSC_MISSING_SIGBUS 1
#define PETSC_MISSING_SIGCHLD 1
#define PETSC_MISSING_SIGCONT 1
#define PETSC_MISSING_SIGHUP 1
#define PETSC_MISSING_SIGKILL 1
#define PETSC_MISSING_SIGPIPE 1
#define PETSC_MISSING_SIGQUIT 1
#define PETSC_MISSING_SIGSTOP 1
#define PETSC_MISSING_SIGSYS 1
#define PETSC_MISSING_SIGTRAP 1
#define PETSC_MISSING_SIGTSTP 1
#define PETSC_MISSING_SIGURG 1
#define PETSC_MISSING_SIGUSR1 1
#define PETSC_MISSING_SIGUSR2 1
#define PETSC_MPICC_SHOW "Unavailable"
#define PETSC_MPIU_IS_COLORING_VALUE_TYPE MPI_UNSIGNED_SHORT
#define PETSC_NEEDS_UTYPE_TYPEDEFS 1
#define PETSC_PREFETCH_HINT_NTA _MM_HINT_NTA
#define PETSC_PREFETCH_HINT_T0 _MM_HINT_T0
#define PETSC_PREFETCH_HINT_T1 _MM_HINT_T1
#define PETSC_PREFETCH_HINT_T2 _MM_HINT_T2
#define PETSC_PYTHON_EXE "/usr/bin/python.exe"
#define PETSC_Prefetch(a,b,c) _mm_prefetch((const char*)(a),(c))
#define PETSC_REPLACE_DIR_SEPARATOR '\\'
#define PETSC_SIGNAL_CAST  
#define PETSC_SIZEOF_ENUM 4
#define PETSC_SIZEOF_INT 4
#define PETSC_SIZEOF_LONG 4
#define PETSC_SIZEOF_LONG_LONG 8
#define PETSC_SIZEOF_SHORT 2
#define PETSC_SIZEOF_SIZE_T 4
#define PETSC_SIZEOF_VOID_P 4
#define PETSC_SLSUFFIX ""
#define PETSC_UINTPTR_T uintptr_t
#define PETSC_UNUSED __attribute((unused))
#define PETSC_USE_AVX512_KERNELS 1
#define PETSC_USE_BACKWARD_LOOP 1
#define PETSC_USE_CTABLE 1
#define PETSC_USE_DMLANDAU_2D 1
#define PETSC_USE_INFO 1
#define PETSC_USE_ISATTY 1
#define PETSC_USE_LOG 1
#define PETSC_USE_MALLOC_COALESCED 1
#define PETSC_USE_MICROSOFT_TIME 1
#define PETSC_USE_PROC_FOR_SIZE 1
#define PETSC_USE_REAL_SINGLE 1
#define PETSC_USE_SINGLE_LIBRARY 1
#define PETSC__BSD_SOURCE 1
#define PETSC__DEFAULT_SOURCE 1
#define PETSC_gid_t int
#define PETSC_uid_t int
#endif
